@@ -310,7 +310,7 @@ reset_start_time (GstPipeline * pipeline)
  *
  * Create a new pipeline with the given name.
  *
- * Returns: newly created GstPipeline
+ * Returns: (transfer full): newly created GstPipeline
  *
  * MT safe.
  */
@@ -343,7 +343,14 @@ pipeline_update_start_time (GstElement * element)
     GST_OBJECT_LOCK (element);
     /* store the current running time */
     if (GST_ELEMENT_START_TIME (pipeline) != GST_CLOCK_TIME_NONE) {
-      GST_ELEMENT_START_TIME (pipeline) = now - element->base_time;
+      if (now != GST_CLOCK_TIME_NONE)
+        GST_ELEMENT_START_TIME (pipeline) = now - element->base_time;
+      else
+        GST_WARNING_OBJECT (element,
+            "Clock %s returned invalid time, can't calculate "
+            "running_time when going to the PAUSED state",
+            GST_OBJECT_NAME (clock));
+
       /* we went to PAUSED, when going to PLAYING select clock and new
        * base_time */
       pipeline->priv->update_clock = TRUE;
@@ -587,7 +594,7 @@ gst_pipeline_handle_message (GstBin * bin, GstMessage * message)
  * Gets the #GstBus of @pipeline. The bus allows applications to receive
  * #GstMessage packets.
  *
- * Returns: a #GstBus, unref after usage.
+ * Returns: (transfer full): a #GstBus, unref after usage.
  *
  * MT safe.
  */
@@ -713,7 +720,7 @@ gst_pipeline_provide_clock_func (GstElement * element)
  *
  * Gets the current clock used by @pipeline.
  *
- * Returns: a #GstClock, unref after usage.
+ * Returns: (transfer full): a #GstClock, unref after usage.
  */
 GstClock *
 gst_pipeline_get_clock (GstPipeline * pipeline)
@@ -727,7 +734,7 @@ gst_pipeline_get_clock (GstPipeline * pipeline)
 /**
  * gst_pipeline_use_clock:
  * @pipeline: a #GstPipeline
- * @clock: the clock to use
+ * @clock: (transfer none): the clock to use
  *
  * Force @pipeline to use the given @clock. The pipeline will
  * always use the given clock even if new clock providers are added
@@ -759,7 +766,7 @@ gst_pipeline_use_clock (GstPipeline * pipeline, GstClock * clock)
 /**
  * gst_pipeline_set_clock:
  * @pipeline: a #GstPipeline
- * @clock: the clock to set
+ * @clock: (transfer none): the clock to set
  *
  * Set the clock for @pipeline. The clock will be distributed
  * to all the elements managed by the pipeline.
